==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/updatepolicymodifiable/updatetrigger/DefaultPeriodic.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.updatepolicymodifiable.updatetrigger;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfyangtypes.rev20130715.yrtietfyangtypes.DateAndTime;
import org.onosproject.yang.gen.v1.yrtietfyangtypes.rev20130715.yrtietfyangtypes.Timeticks;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.updatepolicymodifiable.UpdateTrigger;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of periodic.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultPeriodic extends InnerModelObject implements Periodic {
    protected Timeticks period;
    protected DateAndTime anchorTime;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Timeticks period() {
        return period;
    }

    @Override
    public DateAndTime anchorTime() {
        return anchorTime;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void period(Timeticks period) {
        valueLeafFlags.set(LeafIdentifier.PERIOD.getLeafIndex());
        this.period = period;
    }

    @Override
    public void anchorTime(DateAndTime anchorTime) {
        valueLeafFlags.set(LeafIdentifier.ANCHORTIME.getLeafIndex());
        this.anchorTime = anchorTime;
    }

    @Override
    public int hashCode() {
        return Objects.hash(period, anchorTime, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultPeriodic) {
            DefaultPeriodic other = (DefaultPeriodic) obj;
            return
                Objects.equals(period, other.period) &&
                Objects.equals(anchorTime, other.anchorTime) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("period=" + period)
            .add("anchorTime=" + anchorTime)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultPeriodic.
     */
    public DefaultPeriodic() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/updatepolicymodifiable/updatetrigger/DefaultPeriodic.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.updatepolicymodifiable.updatetrigger;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfyangtypes.rev20130715.yrtietfyangtypes.DateAndTime;
import org.onosproject.yang.gen.v1.yrtietfyangtypes.rev20130715.yrtietfyangtypes.Timeticks;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.updatepolicymodifiable.UpdateTrigger;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of periodic.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultPeriodic extends InnerModelObject implements Periodic {
    protected Timeticks period;
    protected DateAndTime anchorTime;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Timeticks period() {
        return period;
    }

    @Override
    public DateAndTime anchorTime() {
        return anchorTime;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void period(Timeticks period) {
        valueLeafFlags.set(LeafIdentifier.PERIOD.getLeafIndex());
        this.period = period;
    }

    @Override
    public void anchorTime(DateAndTime anchorTime) {
        valueLeafFlags.set(LeafIdentifier.ANCHORTIME.getLeafIndex());
        this.anchorTime = anchorTime;
    }

    @Override
    public int hashCode() {
        return Objects.hash(period, anchorTime, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultPeriodic) {
            DefaultPeriodic other = (DefaultPeriodic) obj;
            return
                Objects.deepEquals(period, other.period) &&
                Objects.deepEquals(anchorTime, other.anchorTime) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("period=" + period)
            .add("anchorTime=" + anchorTime)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultPeriodic.
     */
    public DefaultPeriodic() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
